@@ -21,13 +21,13 @@ double mean_help(NumericVector x, int l, int r) {
 //' @keywords internal
 // [[Rcpp::export]]
 int get_k_star(NumericVector x_star, // bootstrap replicated ts (of full length n)
-           int k_hat, // estimated cpts pos
-           int G_l, // detection bandwidth
-           int G_r) {
+               int k_hat, // estimated cpts pos
+               int G_l, // detection bandwidth
+               int G_r, int G_ll, int G_rr) {
   const int n = x_star.length();
   const int k_hat_ind = k_hat-1; // Recall that R is 1-indexed
-  const int l = std::max(0, k_hat_ind-G_l+1);
-  const int r = std::min(n-1, k_hat_ind+G_r);
+  const int l = std::max(0, k_hat_ind - G_ll + 1);
+  const int r = std::min(n-1, k_hat_ind + G_rr);
   double max_val = -1.0;
   int max_pos = l-1;
   double current_val = -1.0;
@@ -38,7 +38,6 @@ int get_k_star(NumericVector x_star, // bootstrap replicated ts (of full length
       const double scaling = std::sqrt(((double)G_l + (double)G_r) / 
                                        ( (double)(t + 1)*(double)(G_l + G_r - t - 1) ));
       const double mean_l = mean_help(x_star, 0, G_l+G_r-1);
-      //'HC: for (int j=0; j <= t; ++j) {
       for (int j=0; j <= t; ++j) {
         t_val_help += (mean_l - x_star[j]);
       }
@@ -50,7 +49,6 @@ int get_k_star(NumericVector x_star, // bootstrap replicated ts (of full length
       const double scaling = std::sqrt(((double)G_l + (double)G_r) /
                                        ((double)(t + 1 - (n - G_l - G_r))*(double)(n - t - 1)));
       const double mean_r = mean_help(x_star, n-G_l-G_r, n-1);
-      //'HC: for (int j=n-G_l-G_r; j < n; ++j) {
       for (int j = n - G_l - G_r; j <= t; ++j) {
         t_val_help += (mean_r - x_star[j]);
       }
@@ -70,6 +68,7 @@ int get_k_star(NumericVector x_star, // bootstrap replicated ts (of full length
   return max_pos + 1; // Recall that R is 1-indexed
 }
 
+
 //' Obtain bootstrap replicate of time series
 //' @keywords internal
 // [[Rcpp::export]]
@@ -93,8 +92,8 @@ NumericVector bootstrapped_timeSeries(IntegerVector cpts,
 //' @keywords internal
 // [[Rcpp::export]]
 List cpts_bootstrap_help(IntegerMatrix cpts_info,
-                             NumericVector x,
-                             int N_reps) {
+                         NumericVector x,
+                         int N_reps) {
   const IntegerVector cpts = cpts_info(_, 0);
   const int q = cpts.length();
   const int n = x.length();
@@ -127,11 +126,14 @@ List cpts_bootstrap_help(IntegerMatrix cpts_info,
     // note: redundant, may be sped up in future revisions
     //
     NumericVector x_star = bootstrapped_timeSeries(cpts, x);
-
+    
     for (int j=0; j<q; ++j) {
       const int G_l = cpts_info(j, 1);
       const int G_r = cpts_info(j, 2);
-      k_star(iboot,j) = get_k_star(x_star, cpts[j], G_l, G_r);
+      const int G_ll = cpts_info(j, 5);
+      const int G_rr = cpts_info(j, 6);
+      
+      k_star(iboot,j) = get_k_star(x_star, cpts[j], G_l, G_r, G_ll, G_rr);
       k_star1(iboot,j) = k_star(iboot,j)-cpts[j];
       k_star2(iboot,j) = (double)(k_star(iboot,j)-cpts[j]) *
         std::pow(d_hat[j],2.0) / sigma2_hat[j];
